Features
********


This section describes all features that are shipped with this package.


Scenario Features
=================

Main Features
-------------

.. autoclass:: balderhub.textual.lib.scenario_features.AppFeature
    :members:

.. autoclass:: balderhub.textual.lib.scenario_features.TextualControlFeature
    :members:

Page Object Model Feature
-------------------------

.. autoclass:: balderhub.textual.lib.scenario_features.TextualPage
    :members:

Setup Features
==============

.. note::
    This BalderHub project doesn't have any setup features.